# [Black Dashboard](https://app-generator.dev/product/black-dashboard/) Django Integration

Modern template for **Django** built with **[Black Dashboard](https://app-generator.dev/product/black-dashboard/)**, an open-source `Bootstrap` UI Kit released by [Creative-Tim](https://app-generator.dev/agency/creative-tim/).

- [Django Admin Black](https://app-generator.dev/docs/products/django-libs/theme-black-dashboard.html) - Documentation & Support Links
- [Django Black Dashboard](https://app-generator.dev/product/black-dashboard/django/) - The product that uses the library
- [Getting Started with Django](https://app-generator.dev/docs/technologies/django/index.html) - Learn how to code **Django** Projects

<br />

## **Features**

- [Black Dashboard](https://app-generator.dev/product/black-dashboard/) Design Integration
- **Sections Covered**: 
  - `Admin Section`, reserved for `superusers`
  - `All pages` managed by `Django.contrib.AUTH`
  - `Registration` page
  - `Misc pages`: colors, icons, typography, blank-page 
  
<br />

## Pre-built Starters

### [Django Black Dashboard](https://app-generator.dev/product/black-dashboard/django/) `FREE`

> The FREE Version (MIT License) - [Live Demo](https://django-black-dashboard.onrender.com).

- Simple, Easy-to-Extend Codebase
- [Black Dashboard](https://app-generator.dev/product/black-dashboard/) Design Integration
- Dynamic Tables
- Dynamic API
- Charts
- **CLI for Coding Tasks**
  - `Commit/rollback Git Changes`
  - `Backup & restore DB`
  - `Interact with Django Core` via CLI
  - `Update Environment variables`
  - `Update Dependencies`
- Bootstrap 5 Styling 
- Session-based Authentication, Password recovery
- DB Persistence: SQLite (default), can be used with MySql, PgSql
- Docker, CI/CD for Render
- Vite for assets management 

![Django Black Dashboard - Open-Source Django Starter ](https://user-images.githubusercontent.com/51070104/196730732-dda1794b-93ce-48cb-bc5c-182411495512.png)

<br />

### [Django Black Dashboard](https://app-generator.dev/product/black-dashboard-pro/django/) `PRO`

> The premium version provides more features, priority on support, and is more often updated - [Live Demo](https://django-black-pro.onrender.com/).

- Simple, Easy-to-Extend Codebase
- [Black Dashboard](https://app-generator.dev/product/black-dashboard/) PRO Design Integration
- Session-based Authentication, Password recovery
- OAuth (GitHub & Google)
- DB Persistence: SQLite (default), can be used with MySql, PgSql
- Apps
  - Charts
  - Server-Side Datatables
  - API via DRF
  - Extended Users Profile
  - Async Tasks (Celery)
- Docker 
- CI/CD integration for Render 

![Django Black PRO - Premium Django starter built with Black Dashboard design from Creative-Tim](https://github.com/user-attachments/assets/63c1ea5b-6c8b-4e67-8e07-156c3e06895f)

<br />

## `Customize` with [Django App Generator](https://app-generator.dev/tools/django-generator/)

- Access the [App Generator](https://app-generator.dev/tools/django-generator/) page
- Select the preferred design
- (Optional) Design Database: edit models and fields
- (Optional) Edit the fields for the extended user model
- (Optional) Enable OAuth for GitHub
- (Optional) Add Celery (async tasks)
- (Optional) Enable Dynamic API Module
- Docker Scripts
- Render CI/Cd Scripts

**The generated Django project is available as a ZIP Archive and also uploaded to GitHub.**

![Django Generator - User Interface for choosing the Design](https://github.com/user-attachments/assets/b989c434-1c53-49ff-8dda-b46dbfc142ac) 

![Django App Generator - User Interface for Edit the Extended User Model](https://github.com/user-attachments/assets/f1a5fb68-a5ba-49c9-a3ae-91716de09912) 

<br />

---
**[Black Dashboard](https://app-generator.dev/product/black-dashboard/)** Django Integration - Library provided by **[App-Generator](https://app-generator.dev)**
